# processador_imagem

Description. 
The package image_processing is used to:
	Processing:
		- Histogram matching
		- Structural similarity
		-Resize image
	Utils:
		-Read image
		-Save image
		-Plot image
		-Plot result
		-Plot histogram

O pacote image_processing é usado para:
	Processing:
		- Correspondência de histograma
		- Semelhança estrutural
		-Redimensionar imagem
	Utils:
		-Ler imagens
		-Gravar imagens
		-Plot imagem
		-Plot resultado
		-Plot histograma

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install processador_imagem
```

## Author
Uiliam

## License
[MIT](https://choosealicense.com/licenses/mit/)